@@ -21,16 +21,6 @@
 #ifndef __TPB_H__
 #define __TPB_H__
 
-#define POLLTIME 1000
-#define NVRAMDEV "/dev/nvram"
-#ifdef HAVE_LIBXOSD
-#define OSDFONT "-*-lucidatypewriter-medium-r-normal-*-*-250-*-*-*-*-*-*"
-#define OSDCOLOR "BLUE"
-#define OSDTIMEOUT 3
-#define OSDPOS XOSD_bottom
-#define OSDOFFSET 25
-#endif /* HAVE_LIBXOSD */
-
 typedef struct {
 	char tpb; /* ThinkPad button */
 	char kt;  /* ThinkLight */
@@ -46,7 +36,6 @@ typedef struct {
 	char pmb; /* power management mode battery */
 } t_tpb;
 
-void print_usage(const char *prog);
 int get_state(t_tpb *tpbs);
 int fork_app(char *cmd);
 
